# You are only entitled to install this RPM if you bought the game

# CAUTION: BUILDING THIS RPM REQUIRES A LARGE AMOUNT OF STORAGE. ENSURE YOU
# HAVE AT LEAST 3GB FREE WHERE YOUR RPMBUILD DIRECTORIES ARE LOCATED

# We don't want this RPM to be a provider for anything it's bundled with,
# although we remove bundles where practical
AutoProv: no

# Disable any chance of generating a debuginfo package as we cannot use it
%global debug_package %{nil}

# Disable rpath checking. Little we can do with closed source
%global __arch_install_post /usr/lib/rpm/check-buildroot

# We need to filter some requires
%global    _use_internal_dependency_generator 0
%global    __find_requires %{_builddir}/%{name}-%{version}/filter-requires-%{name}.sh

# This package contains mixed binaries so set up some macros
%ifarch x86_64
%global namearch %{name}64
%else
%global namearch %{name}32
%endif

# The software house
%global house runicgames


Name:           Torchlight
Version:        1.15
Release:        3
Epoch:          1
Summary:        Role playing game
Group:          Amusements/Games
License:        Commercial
URL:            http://www.torchlightgame.com
# eff02cb27a818b4d29e399bc8a293d7f  Torchlight-2012-09-26.sh
Source0:        %{name}-2012-09-26.sh
Source1:        torchlight_local.txt
Source2:        torchlight.txt
Source3:        torchlight-libpcre-64
Source4:        torchlight-libpcre-32
NoSource:       0
BuildRequires:  desktop-file-utils
BuildRequires:  xz-lzma-compat
Requires:       mesa-libGL%{?_isa}
Requires:       pulseaudio-libs%{?_isa}
ExclusiveArch:  i686 x86_64

%description
Word of Ember blazed across the land, and the town of Torchlight flared to
life. Ember is the essence of magic and the keystone of alchemy; it lures the
restless with promises of power and riches. Miners burrowed deep beneath the
dirt streets of Torchlight, discovering veins of the ore richer than any found
in living memory- but they were not the first to covet these mines. The miners
broke through into the buried past, a dangerous labyrinth of caverns and ruined
civilizations, twisted creatures and the bones of those who came before. Evil
bubbles up from the depths and threatens to overrun this town as it has so many
others. The heart of a villain has infused the Ember, and his darkness seeps
through the veins. To survive, the townspeople must break the cycle of
destruction; they need a champion who can destroy the evil at its root.
Removing the source of the rot may purify the Ember, but it is a long and
perilous journey. The champion must battle through rock and fire, through lost
cities and ancient tombs, into the palace of the villain himself. The adventure
is set in the mining settlement of Torchlight, a boomtown founded on the
discovery of rich veins of Ember – a rare and mysterious ore with the power to
enchant or corrupt all that it contacts. This corruptive power may have dire
consequences however and players set out into the nearby mountains and depths
below to discover the full extent of Ember’s influence on the civilizations
that have come before. Players will choose from among three character classes,
and venture from the safety of the town of Torchlight into randomly generated
dungeon levels, with a huge variety of creepy monsters, endless variations of
loot to find and quests to complete. The endless randomization ensures a
long-lived gameplay experience.


%prep
%setup -Tqcn %{name}-%{version}
mkdir %{name} misc

# Rip the contents from the nixinstaller package
sh %{SOURCE0} --tar x --to-stdout ./instarchive_all | tar x --lzma -C %{name}
sh %{SOURCE0} --tar x --to-stdout ./subarch | tar x --lzma -C misc

# Rip the arch dependent binaries from the nixinstaller package
%ifarch x86_64
sh %{SOURCE0} --tar x --to-stdout ./instarchive_linux_x86_64 | tar x --lzma -C %{name}
cat misc/deps/CEGUI/CEGUI_files_linux_x86_64 | tar x --lzma -C %{name}
cat misc/deps/SDL2/SDL2_files_linux_x86_64 | tar x --lzma -C %{name}
cat misc/deps/fmod/fmod_files_linux_x86_64 | tar x --lzma -C %{name}
cat misc/deps/Ogre/Ogre_files_linux_x86_64 | tar x --lzma -C %{name}
%else
sh %{SOURCE0} --tar x --to-stdout ./instarchive_linux_x86 | tar x --lzma -C %{name}
cat misc/deps/CEGUI/CEGUI_files_linux_x86 | tar x --lzma -C %{name}
cat misc/deps/SDL2/SDL2_files_linux_x86 | tar x --lzma -C %{name}
cat misc/deps/fmod/fmod_files_linux_x86 | tar x --lzma -C %{name}
cat misc/deps/Ogre/Ogre_files_linux_x86 | tar x --lzma -C %{name}
%endif

# Move this for later
mv %{name}/README.linux .


%build
cat >%{namearch}.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
%ifarch x86_64
Name=Torchlight (64bit)
%else
Name=Torchlight (32bit)
%endif
Comment=%{summary}
Exec=%{_bindir}/%{namearch}
Icon=%{_datadir}/%{namearch}/%{name}.png
Terminal=false
Type=Application
StartupNotify=false
Categories=Game;RolePlaying;
EOF

# Create the wrapper for /usr/bin
cat >%{namearch}.wrapper <<EOF
#!/bin/bash
# Simple wrapper script to launch %{name}
#

# Installing default settings prevents crash on first time start
if [ -d "\${HOME}" ] ; then
    if [ ! -e "\${HOME}/.runicgames/Torchlight" ] ; then
        mkdir -p "\${HOME}/.runicgames/Torchlight"
        cp %{_sysconfdir}/default/%{namearch}/local_settings.txt "\${HOME}/.runicgames/Torchlight"
        cp %{_sysconfdir}/default/%{namearch}/settings.txt "\${HOME}/.runicgames/Torchlight"
    fi
fi

pushd %{_datadir}/%{namearch} >/dev/null
%ifarch x86_64
./%{name}.bin.x86_64 "\$@"
%else
./%{name}.bin.x86 "\$@"
%endif
popd >/dev/null
EOF

cat >filter-requires-%{name}.sh <<EOF
#!/bin/sh
# Filter requires for libraries that are bundled

if [ -x /usr/lib/rpm/redhat/find-requires ] ; then
    FINDREQ=/usr/lib/rpm/redhat/find-requires
else
    FINDREQ=/usr/lib/rpm/find-requires
fi

\$FINDREQ \$* | sed -e '/libCEGUIOgreRenderer-1.6.5.so/d' | sed -e '/libOgreMain-1.6.5.so/d' | \
                sed -e '/libSDL2-2.0.so/d' | sed -e '/libfmodex-4.36.21.so/d' | \
%if 0%{?fedora} > 17
sed -e '/libpcre.so.0/d' | \
%endif
                sed -e '/libCEGUI/d' | sed -e '/libPlugin_PCZSceneManager.so/d'
EOF

chmod 0755 filter-requires-%{name}.sh


%install
mkdir -p %{buildroot}%{_bindir} \
         %{buildroot}%{_datadir}/applications \
         %{buildroot}%{_datadir}/%{namearch} \
         %{buildroot}%{_sysconfdir}/default/%{namearch}

cp -a %{name}/* %{buildroot}%{_datadir}/%{namearch}

# Installing default settings prevents the game crashing on first startup
install -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/default/%{namearch}/local_settings.txt
install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/default/%{namearch}/settings.txt

desktop-file-install --vendor %{house} \
                     --dir %{buildroot}%{_datadir}/applications \
                     %{namearch}.desktop

install -m0755 %{namearch}.wrapper %{buildroot}%{_bindir}/%{namearch}

%if 0%{?fedora} > 17
# This only needs doing on F18 or newer
%ifarch x86_64
install -m0755 %{SOURCE3} %{buildroot}%{_datadir}/%{namearch}/%{_lib}/libpcre.so.0
%else
install -m0755 %{SOURCE4} %{buildroot}%{_datadir}/%{namearch}/%{_lib}/libpcre.so.0
%endif
%endif


%files
%defattr(-,root,root,-)
%doc README.linux
%config(noreplace) %{_sysconfdir}/default/%{namearch}
%{_bindir}/%{namearch}
%{_datadir}/%{namearch}
%{_datadir}/applications/%{house}-%{namearch}.desktop


%changelog
* Wed Feb 06 2013 RPMBuilder <> 1.15-3
- Added epoch
- Replaced pulseaudio-utils with pulseaudio-libs
- Bundle libpcre.so.0 from F17 for use with F18 only as it doesn't have it

* Fri Oct 05 2012 RPMBuilder <> 1.15-20120926
- Updated to release 1.15-20120926

* Tue Sep 25 2012 RPMBuilder <> 1.15-20120924
- Updated to release 1.15-20120924

* Sun Sep 23 2012 RPMBuilder <> 1.0-20120920
- Initial Release