# IMPORTANT NOTES
#
# 1. You are only entitled to install this RPM if you bought the game
# 2. The "source" actually includes pre-built 32bit binaries
# 3. On 64bit systems the source RPM should be built along the lines of:
#    setarch i386 rpmbuild --target=i686 -ba <specfile>

# CAUTION: BUILDING THIS RPM REQUIRES A LARGE AMOUNT OF STORAGE. ENSURE YOU
# HAVE AT LEAST 7GB FREE WHERE YOUR RPMBUILD DIRECTORIES ARE LOCATED

# We don't want this RPM to be a provider for anything it's bundled with,
# although we remove bundles where practical
AutoProv: no

# Disable rpath checking. Little we can do with closed source
%define __arch_install_post /usr/lib/rpm/check-buildroot

# We need to filter some requires
%define    _use_internal_dependency_generator 0
%define    __find_requires %{_builddir}/%{name}-%{version}/filter-requires-%{name}.sh

Name:           trine32
Version:        1.08
Release:        2%{?dist}
Summary:        A 3D fantasy platform game with puzzles
Group:          Amusements/Games
License:        Commercial
URL:            http://trine-thegame.com
# 7c84061f9f74052a45d15c35df18d143  TrineUpdate4.32.run
Source0:        TrineUpdate4.32.run
NoSource:       0
BuildRequires:  desktop-file-utils
Requires:       pulseaudio-utils%{?_isa}
Requires:       libCg%{?_isa}
BuildArch:      i686


%description
Trine is a physics-based action game where three characters allow clever
solutions to challenges created by hazardous puzzles and threatening enemies.
The game play is based on fully interactive physics - each character's
different abilities and tactics can be used to invent new ways to overcome
obstacles and save the kingdom!


%prep
%setup -Tqcn %{name}-%{version}

mkdir unpacked

# We are actually unpacking a mojo setup binary here. We need to force a true
# result so rpm does not fail as zip warns about superfluous data at the
# start and returns a non-zero result. That warning can be ignored.
echo "YOU CAN INGORE THE WARNING: extra bytes at beginning or within zipfile"
true `unzip -qq %{SOURCE0} -d unpacked`

# Fix some permissions
find unpacked/data -type d -exec chmod 0755 '{}' \;
find unpacked/data -type f -exec chmod 0644 '{}' \;
chmod 0644 unpacked/Trine_Manual_linux.pdf

# Remove bundled libraries and extraneous files
rm -f unpacked/lib32/lib{asound_module_pcm_pulse.so,asound.so.2,direct-1.0.so.0,CgGL.so,Cg.so,directfb-1.0.so.0,expat.so.1,\
FLAC.so.8,fusion-1.0.so.0,gcc_s.so.1,gdbm.so.3,gmodule-2.0.so.0,gomp.so.1,ICE.so.6,jpeg.so.62,mikmod.so.2,m.so.6,ogg.so.0,\
openal.so.1,pcre.so.3,png12.so.0,rt.so.1,SDL-1.2.so.0,SDL_image-1.2.so.0,SDL_sound-1.0.so.1,SDL_ttf-2.0.so.0,selinux.so.1,\
smpeg-0.4.so.0,SM.so.6,speex.so.1,stdc++.so.6,tiff.so.4,vga.so.1,vorbisfile.so.3,vorbis.so.0,X11.so.6,x86.so.1,Xau.so.6,\
xcb-render.so.0,xcb-render-util.so.0,xcb.so.1,xcb-xlib.so.0,Xcomposite.so.1,Xcursor.so.1,Xdamage.so.1,Xdmcp.so.6,Xext.so.6,\
Xfixes.so.3,Xinerama.so.1,Xi.so.6,xml2.so.2,Xmu.so.6,Xrender.so.1,Xt.so.6,z.so.1}

rm -f unpacked/{createShortcuts.sh,removeShortcuts.sh,trine-bin,trine-bin64,trine-launcher,trine-launcher64}
rm -rf unpacked/lib64

# Move for later
mv unpacked/{Trine_Manual_linux.pdf,Trine_updates.txt} .
sed -i 's/\r//' Trine_updates.txt


%build
cat >%{name}.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Trine (32bit)
GenericName=3D Fantasy Puzzle Platformer
Comment=%{summary}
Exec=%{_bindir}/%{name}
Icon=%{_datadir}/%{name}/Trine.xpm
Terminal=false
Type=Application
StartupNotify=false
Categories=Game;AdventureGame;
EOF

# Create the wrapper for /usr/bin
cat >%{name}.wrapper <<EOF
#!/bin/bash
# Sound for trine normally works when not using the bundled libraries but
# we can launch with padsp to get sound in all cases. To disable padsp:
# touch \${HOME}/.%{name}-nopa

pushd %{_datadir}/%{name} >/dev/null

if [ -e "\${HOME}/.%{name}-nopa" ] || [ ! -e "/usr/bin/padsp" ] ; then
    ./trine-launcher32 $*
else
    padsp ./trine-launcher32 $*
fi

popd >/dev/null
EOF

cat >filter-requires-%{name}.sh <<EOF
#!/bin/sh
# Filter requires for libraries that are bundled

if [ -x /usr/lib/rpm/redhat/find-requires ] ; then
    FINDREQ=/usr/lib/rpm/redhat/find-requires
else
    FINDREQ=/usr/lib/rpm/find-requires
fi

\$FINDREQ $* | sed -e '/libboost_filesystem.so/d' | \
               sed -e '/libboost_regex.so/d' | \
               sed -e '/libboost_system.so/d' | \
               sed -e '/libboost_thread-mt.so/d' | \
               sed -e '/libPhysXCore.so/d' | \
               sed -e '/libPhysXLoader.so/d' | \
               sed -e '/libavformat.so/d' | \
               sed -e '/libicui18n.so/d' | \
               sed -e '/libavcodec.so/d' | \
               sed -e '/libGLEW.so/d' | \
               sed -e '/libicuuc.so/d' | \
               sed -e '/libicudata.so/d' | \
               sed -e '/libavutil.so/d' | \
               sed -e '/libcv.so/d' | \
               sed -e '/libcxcore.so/d' | \
               sed -e '/libswscale.so/d' \
               sed -e '/NxCharacter.so/d' | \
               sed -e '/NxCooking.so/d'
EOF

chmod 0755 filter-requires-%{name}.sh


%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_datadir}/applications
cp -a unpacked/* %{buildroot}%{_datadir}/%{name}

desktop-file-install --vendor frozenbyte \
    --dir %{buildroot}%{_datadir}/applications \
    %{name}.desktop

# Install the fixed launcher to push sound through pulseaudio
install -m0755 %{name}.wrapper %{buildroot}%{_bindir}/%{name}

pushd %{buildroot}%{_datadir}/%{name} > /dev/null
ln -s trine-bin32 trine-bin
popd > /dev/null


%files
%defattr(-,root,root,-)
%doc Trine_Manual_linux.pdf Trine_updates.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/frozenbyte-%{name}.desktop


%changelog
* Thu Nov 10 2011 RPMBuilder <> 1.08-2%{?dist}
- Updated to 1.08 build 4
- Don't remove NxCharacter.so, NxCooking.so libs

* Mon Nov 07 2011 RPMBuilder <> 1.08-1%{?dist}
- Initial RPM Release
